@@ -25,16 +25,17 @@
 #include "synconfig.h"
 #include <kdebug.h>
 #include <qpushbutton.h>
+#include <qwidget.h>
 
 #include <klocale.h>   
 
 AdjBorderWizard::AdjBorderWizard() : AdjBorderWizardBase()
 { 
   KLocale::setMainCatalogue( "ksynaptics" );
-  frameLeft->displayPosition( LeftEdge );
-  frameRight->displayPosition( RightEdge );
-  frameUpper->displayPosition( TopEdge );
-  frameLower->displayPosition( BottomEdge );
+  frameLeft->displayState( LeftEdge );
+  frameRight->displayState( RightEdge );
+  frameUpper->displayState( TopEdge );
+  frameLower->displayState( BottomEdge );
 
   hide();
   clearMeasuredResults();
@@ -47,6 +48,13 @@ AdjBorderWizard::AdjBorderWizard() : AdjBorderWizardBase()
 
   saveState();
   disableState();
+
+//  setMouseTracking( true );
+}
+
+AdjBorderWizard::~AdjBorderWizard()
+{
+//    releaseMouse();
 }
 
 void AdjBorderWizard::clearMeasuredResults()
@@ -56,6 +64,7 @@ void AdjBorderWizard::clearMeasuredResults()
 
 void AdjBorderWizard::mouseMoveEvent( QMouseEvent * )
 {
+    kdDebug() << k_funcinfo << endl;
   m_evCnt++;
 
   m_avgX += TouchPad::absCoordX();
@@ -93,7 +102,7 @@ void AdjBorderWizard::allowProceed()
   m_X[i-1] = m_avgX / m_evCnt;
   m_Y[i-1] = m_avgY / m_evCnt;
 
-  kdDebug() << "X:Y is " << m_X[i-1] << ":" << m_Y[i-1] << endl;
+  kdDebug() << k_funcinfo << "X:Y is " << m_X[i-1] << ":" << m_Y[i-1] << endl;
 
   // last page?
   if ( i == pageCount() - 1 )
@@ -110,7 +119,7 @@ void AdjBorderWizard::accept()
   QRect edges = QRect( QPoint( m_X[ 0 ] - offset, m_Y[ 2 ] - offset ),
                QPoint( m_X[ 1 ] + offset, m_Y[ 3 ] + offset ) );
   SynConfig::setEdges( edges );
-  kdDebug() << "updated changed borders!" << edges << endl;
+  kdDebug() << k_funcinfo << "updated changed borders!" << edges << endl;
   emit changed();
 
   restoreState();
@@ -119,14 +128,14 @@ void AdjBorderWizard::accept()
 
 void AdjBorderWizard::reject()
 {
-  kdDebug() << "reject changed borders!" << endl;
+  kdDebug() << k_funcinfo << "reject changed borders!" << endl;
   restoreState();
   done( QDialog::Rejected );
 }
 
 void AdjBorderWizard::saveState()
 {
-  kdDebug() << "save pad states" << endl;
+  kdDebug() << k_funcinfo << "save pad states" << endl;
   m_edgeMotion    = TouchPad::isEdgeMotionEnabled();
   m_vertDelta     = TouchPad::verticalScrollDelta();
   m_horizDelta    = TouchPad::horizontalScrollDelta();
@@ -135,16 +144,18 @@ void AdjBorderWizard::saveState()
 
 void AdjBorderWizard::restoreState()
 {
-  kdDebug() << "restore pad states" << endl;
+  kdDebug() << k_funcinfo << "restore pad states" << endl;
   TouchPad::setEdgeMotionEnabled( m_edgeMotion );
   TouchPad::setVerticalScrollDelta( m_vertDelta );
   TouchPad::setHorizontalScrollDelta( m_horizDelta );
   TouchPad::setCircularScrollEnabled( m_circScrolling );
+
+  releaseMouse();
 }
 
 void AdjBorderWizard::disableState()
 {
-  kdDebug() << "disable pad states" << endl;
+  kdDebug() << k_funcinfo << "disable pad states" << endl;
   TouchPad::setEdgeMotionEnabled( FALSE );
   TouchPad::setVerticalScrollDelta( 0 );
   TouchPad::setHorizontalScrollDelta( 0 );
