@@ -25,37 +25,49 @@
 #include <qcolor.h>
 #include <qcursor.h>
 #include <qevent.h>
+#include <qpixmap.h>
+#include <kdebug.h>
 
-
-myFrame::myFrame() : QFrame()
-{
-    sTrigger = AllCorners;
-    setFrameShape(QFrame::Box);
-}
+#include "fingerprint.xpm"
 
 myFrame::myFrame(QWidget* parent, const char* name) : QFrame(parent, name)
 {
-    sTrigger = AllCorners;
+    kdDebug() << k_funcinfo << endl;
+    
+    mPadMode = NoTrigger;
     setFrameShape(QFrame::Box);
+    mPixmap = new QPixmap( fingerprint );
+}
+
+myFrame::~myFrame()
+{
+    kdDebug() << k_funcinfo << endl;
+    
+    delete mPixmap;
 }
 
 void myFrame::mouseMoveEvent(QMouseEvent *)
 {
+    kdDebug() << k_funcinfo << endl;
 }
 
-void myFrame::displayPosition(int scrollTrigger)
+void myFrame::displayState(int i)
 {
+    kdDebug() << k_funcinfo << endl;
+    
     // range checking
-    if ( ( scrollTrigger < AllCorners ) || ( scrollTrigger > TopLeftCorner ) )
-        sTrigger = NoTrigger;
+    if ( ( i < NoTrigger ) or ( i >= PadModeMax ) )
+        mPadMode = NoTrigger;
     else
-        sTrigger = (ScrollTrigger) scrollTrigger;
+        mPadMode = (PadMode) i;
 
     repaint();
 }
-    
+
 void myFrame::paintEvent(QPaintEvent *event)
 {
+    kdDebug() << k_funcinfo << endl;
+    
     const int r = 10;
     
     // permutations...
@@ -76,22 +88,40 @@ void myFrame::paintEvent(QPaintEvent *event)
     // erase whole frame
     myPainting.setBrush( QPainter::SolidPattern );
     myPainting.setBrush( QColor( "White" ) );
-    myPainting.drawRect( 0,0,width(),height() );
+    myPainting.drawRect( 0, 0, width(), height() );
     
     // draw grid
+    // TODO improve this drawing
     myPainting.setBrush( QPainter::CrossPattern );
     myPainting.drawRect( x1, y1, x2+r/2, y2+r/2 );
     
     // paint the grid only?
-    if ( sTrigger == NoTrigger ) return;
+    if ( mPadMode == NoTrigger ) return;
+
+
+    // draw the proper amout of finger tips 
+    if ( mPadMode >= OneFinger )
+        myPainting.drawPixmap( 0, 0, *mPixmap ); 
+
+    if ( mPadMode >= TwoFingers )
+        myPainting.drawPixmap( 37, 0, *mPixmap );
     
-    myPainting.setPen( QColor( "Red" ) );
-    myPainting.setBrush( QColor( "Red") );
+    if ( mPadMode >= ThreeFingers )
+        myPainting.drawPixmap( 20, 27, *mPixmap );
     
-    if ( p[sTrigger] & 1 ) myPainting.drawEllipse( x1+o, y1+o, r, r );
-    if ( p[sTrigger] & 2 ) myPainting.drawEllipse( x2-o-r, y1+o, r, r );
-    if ( p[sTrigger] & 4 ) myPainting.drawEllipse( x2-o-r, y2-o-r, r, r );
-    if ( p[sTrigger] & 8 ) myPainting.drawEllipse( x1+o, y2-o-r, r, r );
+
+    // otherwise draw the corners/edges
+    // TODO improve this drawing
+    if ( mPadMode != OneFinger and mPadMode != TwoFingers and mPadMode != ThreeFingers )
+    {
+        myPainting.setPen( QColor( "Red" ) );
+        myPainting.setBrush( QColor( "Red") );
+    
+        if ( p[mPadMode] & 1 ) myPainting.drawEllipse( x1+o, y1+o, r, r );
+        if ( p[mPadMode] & 2 ) myPainting.drawEllipse( x2-o-r, y1+o, r, r );
+        if ( p[mPadMode] & 4 ) myPainting.drawEllipse( x2-o-r, y2-o-r, r, r );
+        if ( p[mPadMode] & 8 ) myPainting.drawEllipse( x1+o, y2-o-r, r, r );
+    }
 }
 
 #include "myframe.moc"
