@@ -20,26 +20,74 @@
 #include <qbuttongroup.h>
 #include <qcheckbox.h>
 #include <qlabel.h>
+#include <qstring.h>
 #include <qslider.h>
 #include <qradiobutton.h>
+#include <qlabel.h>
 
+#include <kapplication.h>
+#include <dcopclient.h>
 #include <kmessagebox.h>
 #include <kcombobox.h>
 #include <kdebug.h>
 #include <klocale.h>
 #include <kprocess.h>
 
+#include <synaptics.h>
+
 #include "myframe.h"
 #include "synconfig.h"
 #include "synconfigwidget.h"
 
 SynConfigWidget::SynConfigWidget( QWidget *parent, const char *name )
-  : SynConfigWidgetBase( parent, name ),
-    m_borderWizard( 0 )
+  : SynConfigWidgetBase( parent, name ), m_borderWizard(0)
 {
-  KLocale::setMainCatalogue( "ksynaptics" );
+    KLocale::setMainCatalogue( "ksynaptics" );
 
-  connect( cmbTapFinger, SIGNAL( activated( int ) ), this, SLOT( tapFingerChanged( int ) ) );
+    connect( cmbTapFinger, SIGNAL( activated( int ) ), this, SLOT( tapFingerChanged( int ) ) );
+    connect( cmbCircTrigger, SIGNAL( activated( int ) ), this, SLOT( scrollTriggerChanged( int ) ) );
+    connect( generalSwitchOffRB, SIGNAL( clicked() ), this, SLOT( disableNearlyEverything() ) );
+
+    // update version information
+    QString libText = libVersionTL->text();
+    QString drvText = driverVersionTL->text();
+    libText.append( " <b>" + QString( Synaptics::Pad::libraryStr().c_str() ) + "</b>" );
+    
+    if ( Pad::driverKind() == DV_OUTDATED )
+        drvText.append( " <b>" + QString( "Outdated" ) + "</b>" );
+    else
+        drvText.append( " <b>" + QString( Synaptics::Pad::driverStr().c_str() ) + "</b>" );
+    
+    libVersionTL->setText( libText );
+    driverVersionTL->setText( drvText );
+
+    kdDebug() << k_funcinfo << "Has SHM: " << Synaptics::Pad::hasShm() << endl;
+    // check whether the driver is operateable
+    if ( !Synaptics::Pad::hasShm() )
+    {
+        KMessageBox::information(this,
+            i18n("Shared Memory is not accessible.\n" 
+                "Please add the option 'UseShm ''true''' into the " 
+                "touch pad section of /etc/X11/xorg.conf\n"),
+            i18n("Touch pad configuration inaccessible")
+        );
+    }
+    else
+    {
+        kdDebug() << k_funcinfo << "Has driver: " << Synaptics::Pad::hasDriver() << endl;
+        if ( !Synaptics::Pad::hasDriver() )
+        {
+            KMessageBox::information(this,
+                tr2i18n(
+                    "No usable driver has been found!\n"
+                    "Either your driver is not correctly installed or "
+                    "you are using a wrong version.\n"
+                    "You need at least driver version 0.14.4!\n"
+                ),
+                tr2i18n("No driver found")
+            );
+        }
+    }
 }
 
 void SynConfigWidget::useTappingChanged( bool b )
@@ -48,6 +96,7 @@ void SynConfigWidget::useTappingChanged( bool b )
   lblShort1->setEnabled( b );
   slTapTime->setEnabled( b );
   lblLong1->setEnabled( b );
+  cbFastTaps->setEnabled( b );
 
   emit changed();
 }
@@ -71,7 +120,40 @@ void SynConfigWidget::useDockingChanged( bool b )
 
 void SynConfigWidget::tapFingerChanged( int index )
 {
-  kdDebug() << "tapFingerChanged" << endl;
+  kdDebug() << k_funcinfo << endl;
+
+  myFrame::PadMode padMode;
+  
+  switch ( index )
+  {
+      case 0:
+          padMode = myFrame::RightTopCorner;
+          break;
+      case 1:
+          padMode = myFrame::RightBottomCorner;
+          break;
+      case 2:
+          padMode = myFrame::LeftTopCorner;
+          break;
+      case 3:
+          padMode = myFrame::LeftBottomCorner;
+          break;
+      case 4:
+          padMode = myFrame::OneFinger;
+          break;
+      case 5:
+          padMode = myFrame::TwoFingers;
+          break;
+      case 6:
+          padMode = myFrame::ThreeFingers;
+          break;
+      default:
+          padMode = myFrame::NoTrigger;
+          break;
+  }
+
+  tappingStateFrame->displayState( padMode );
+  
   bgTapButton->setButton( finger[index] );
 
   emit changed();
@@ -84,6 +166,14 @@ void SynConfigWidget::tapButtonChanged( int id )
   emit changed();
 }
 
+void SynConfigWidget::scrollTriggerChanged( int index )
+{
+    kdDebug() << k_funcinfo << endl;
+    scrollingStateFrame->displayState( index );
+    
+    emit changed();
+}
+
 void SynConfigWidget::horizScrollChanged( bool b )
 {
   lblSlow1->setEnabled( b );
@@ -109,7 +199,7 @@ void SynConfigWidget::circScrollChanged( bool b )
   lblFast3->setEnabled( b );
   lblUse->setEnabled( b );
   cmbCircTrigger->setEnabled( b );
-  cornerEdgeFrame->setEnabled( b );
+  scrollingStateFrame->setEnabled( b );
 
   emit changed();
 }
@@ -122,48 +212,48 @@ void SynConfigWidget::alpsOptionClicked( )
             this, 
             i18n("This will override the currently set edge borders! Change really?"),
             i18n("Switching Edge Border Defaults"), i18n("Change"), i18n("Do Not Change")
-	);
+    );
 
     if ( really == KMessageBox::No )
     {
         // undo the changes!
         cbTreatAsALPS->toggle();
-	return;
+    return;
     }
-    
+
     if ( cbTreatAsALPS->isChecked() )
     {
       QRect edges = QRect( QPoint( 120, 120 ), QPoint( 830, 650 ) );
       SynConfig::setEdges( edges );
-      kdDebug() << "use ALPS edges" << endl;
+      kdDebug() << k_funcinfo << "use ALPS edges" << endl;
     } 
     else
     {
       QRect edges = QRect( QPoint( 1700, 1700 ), QPoint( 5300, 4200 ) );
       SynConfig::setEdges( edges );
-      kdDebug() << "use Synaptics edges" << endl;
+      kdDebug() << k_funcinfo << "use Synaptics edges" << endl;
     }
-    
+
     emit changed();
 
     KMessageBox::information(
         this,
-	i18n("The new settings have been loaded. Press apply to activate!"),
-	i18n("Switching Edge Border Defaults")
+    i18n("The new settings have been loaded. Press apply to activate!"),
+    i18n("Switching Edge Border Defaults")
     );
 }
 
 void SynConfigWidget::widgetModified()
 {
-  emit changed();
+    emit changed();
 }
 
 void SynConfigWidget::invokeBorderWizard()
 {
   if (m_borderWizard)  {
     // we must've canceled before, restart from beginning
+    kdDebug() << k_funcinfo << "reusing old wizard..." << endl;
     m_borderWizard->showPage( m_borderWizard->page( 0 ) ); 
-    kdDebug() << "reuse old wizard..." << endl;
   }
   else {
     m_borderWizard = new AdjBorderWizard();
@@ -171,7 +261,7 @@ void SynConfigWidget::invokeBorderWizard()
   }
 
   m_borderWizard->show();
-  kdDebug() << "invoke wizard..." << endl;
+  kdDebug() << k_funcinfo << "invoke wizard..." << endl;
 }
 
 void SynConfigWidget::load()
@@ -184,8 +274,11 @@ void SynConfigWidget::load()
   int tpState = SynConfig::enableTouchPad();
 
   if ( tpState == SynConfig::EnumEnableTouchPad::NoTaps ) tpState = SynConfig::EnumEnableTouchPad::Enabled;
-  kdDebug() << tpState << endl;
-	  
+  kdDebug() << k_funcinfo << tpState << endl;
+
+  if ( tpState  == SynConfig::EnumEnableTouchPad::Disabled )
+      disableNearlyEverything();
+      
   bgTouchPadSwitch->setButton( tpState );
   slSensitivity->setValue( SynConfig::sensitivity() );
   cbSmartMode->setChecked( SynConfig::enableSmartMode() );
@@ -205,7 +298,7 @@ void SynConfigWidget::load()
   finger[5] = SynConfig::tapTwoFingers();
   finger[6] = SynConfig::tapThreeFingers();
 
-  tapFingerChanged( 0 );
+  tapFingerChanged( cmbTapFinger->currentItem() );
   useTappingChanged( cbEnableTapping->isChecked() );
   cbFastTaps->setChecked( SynConfig::fastTaps() );
 
@@ -223,16 +316,22 @@ void SynConfigWidget::load()
   horizScrollChanged( cbHorizScrolling->isChecked() );
   vertScrollChanged( cbVertScrolling->isChecked() );
   circScrollChanged( cbCircScrolling->isChecked() );
+
+  // initialize the edge widget with the proper value
+  scrollingStateFrame->displayState( SynConfig::circularScrollTrigger() );
+  
+  if (!( Pad::hasDriver() and Pad::hasShm() ))
+      disableEverything();
 }
 
 void SynConfigWidget::save()
 {
-  kdDebug() << "here?" << endl;
+  kdDebug() << k_funcinfo << "here?" << endl;
   // Docking
   enableDocking( generalDockingCB->isChecked() );
   SynConfig::setEnableDocking( generalDockingCB->isChecked() );
 
-	
+    
   // General Tab
   SynConfig::setEnableTouchPad( bgTouchPadSwitch->selectedId() );
   SynConfig::setSensitivity( slSensitivity->value() );
@@ -269,23 +368,40 @@ void SynConfigWidget::save()
 
 void SynConfigWidget::enableDocking( bool yesNo )
 {
-  kdDebug() << "switch docking " << QString( yesNo? "on":"off" ) << endl;
+    kdDebug() << k_funcinfo << "switch docking " << (yesNo ? "on" : "off") << endl;
+    // set autostart link or remove it!
+    if (yesNo)
+    {
+        KApplication::kdeinitExec("syndock", QStringList(), 0, 0);
+    }
+    else
+    {
+        KApplication::dcopClient()->send("syndock", "MainApplication-Interface",
+            "quit()", QString::null);
+    }
+    kdDebug() << k_funcinfo << "done" << endl;
+}
 
-  // set autostart link or remove it!
-  if (yesNo)
-  {
-	m_sdstart.clearArguments();
-    m_sdstart << "syndock";
-    m_sdstart.start();
-  }
-  else
-  {
-	m_sdkill.clearArguments();
-    m_sdkill << "killall" << "syndock";
-    m_sdkill.start();
-  }
-  
-  kdDebug() << "..done!" << endl;
+void SynConfigWidget::disableEverything( bool onOff )
+{
+    kdDebug() << k_funcinfo << endl;
+    disableNearlyEverything( onOff );
+    bgTouchPadSwitch->setDisabled( onOff );
+}
+
+void SynConfigWidget::disableNearlyEverything( bool onOff)
+{
+    kdDebug() << k_funcinfo << endl;
+    grpSmartMode->setDisabled( onOff );
+    grpSensitivity->setDisabled( onOff );
+    grpTouchPadBorders->setDisabled( onOff );
+    grpTapEmulation->setDisabled( onOff );
+    grpFingers->setDisabled( onOff );
+    cbFastTaps->setDisabled( onOff );
+    grpScrolling->setDisabled( onOff );
+    grpCircScrolling->setDisabled( onOff );
+    grpOnAnEdge->setDisabled( onOff );
+    generalDockingCB->setDisabled( onOff );
 }
 
 #include "synconfigwidget.moc"
