@@ -23,8 +23,6 @@
 #include "synconfigwidgetbase.h"
 #include "adjborderwizard.h"
 
-#include <kprocess.h>
-
 
 class SynConfigWidget : public SynConfigWidgetBase
 {
@@ -41,6 +39,7 @@ class SynConfigWidget : public SynConfigWidgetBase
     void useDockingChanged( bool );
     void tapFingerChanged( int );
     void tapButtonChanged( int );
+    void scrollTriggerChanged( int );
     void horizScrollChanged( bool );
     void vertScrollChanged( bool );
     void circScrollChanged( bool );
@@ -51,12 +50,15 @@ class SynConfigWidget : public SynConfigWidgetBase
 
     void enableDocking( bool );
 
+    // disables completely everything ( in case there's no usable driver )
+    void disableEverything( bool = true );
+    // disabled everything ( when the pad is disabled on user's demand )
+    void disableNearlyEverything( bool = true );
+
   signals:
     void changed();
 
   private:
     AdjBorderWizard *m_borderWizard;
-    // FIXME no kprocess, will not be necessary for KDE4 since Qt4 handles file links
-    KProcess m_proc, m_sdkill, m_sdstart;
 };
 #endif // SYNCONFIGWIDGET_H
