@@ -22,31 +22,11 @@
 #define _TOUCHPAD_H_
 
 #include <qrect.h>
+#include <qstring.h>
 
-#include "synshm.h"
-
-typedef enum
-{
-  NoTrigger=-1,
-  AllCorners=0,
-  TopEdge,
-  TopRightCorner,
-  RightEdge,
-  BottomRightCorner,
-  BottomEdge,
-  BottomLeftCorner,
-  LeftEdge,
-  TopLeftCorner
-} ScrollTrigger;
-
-typedef enum
-{
-  None=0,
-  Left,
-  Middle,
-  Right
-} Button;
+#include <synaptics.h>
 
+using namespace Synaptics;
 
 class TouchPad
 {
@@ -59,6 +39,7 @@ class TouchPad
     // 0:enabled
     // 1:disabled
     // 2:notaps
+    static QString driverVersion();
     static int isEnabled();
     static QRect edges();
     static bool isTappingEnabled();
@@ -87,9 +68,7 @@ class TouchPad
     static void setTapTime( int time );
     static void setTapAction( TapType type, int action );
     static void setSensitivity( int value );
-//	static void setHorizontalScrollEnabled( bool enable );
     static void setHorizontalScrollDelta( int delta );
-//	static void setVerticalScrollingDelta( bool enable );
     static void setVerticalScrollDelta( int delta );
     static void setCircularScrollEnabled( bool enable );
     static void setEdgeMotionEnabled( bool enable );
@@ -104,7 +83,6 @@ class TouchPad
 protected:
     TouchPad();
     static TouchPad *m_self;
-    SynapticsSHM *m_synShm;
 };
 
 #endif
